pub struct Client { /* private fields */ }Expand description
Client is a struct that represents a client to the Codecov API.
Implementations
Sourceimpl Client
impl Client
pub fn new_from_env() -> Result<Client, Error>
pub fn new(token: String) -> Client
Sourcepub fn get_all_repos(&self, owner: &Owner) -> Result<Vec<Repo>, Error>
pub fn get_all_repos(&self, owner: &Owner) -> Result<Vec<Repo>, Error>
get_all_repos returns a list of all repos for a given owner. /repos endpoint returns a list of repos for a given owner with pagination. This function will make multiple requests to get all repos.
pub fn get_commits(&self, author: &Author) -> Result<CommitsAPIResponse, Error>